@@ -46,6 +46,7 @@ get_etoxid <- function(query,
                        verbose = getOption("verbose")) {
 
   if (!ping_service("etox")) stop(webchem_message("service_down"))
+  names(query) <- query
 
   clean_char <- function(x) {
     # rm \n \t
@@ -63,11 +64,14 @@ get_etoxid <- function(query,
     warning("match = 'best' only makes sense when querying chemical names. ")
   }
   foo <- function(query, from, match, verbose) {
+    if (from == "cas"){
+      query <- as.cas(query, verbose = verbose)
+    }
     if (is.na(query)) {
       if (verbose) webchem_message("na")
       return(tibble("query" = query, "match" = NA, "etoxid" = NA))
     }
-    if(verbose) webchem_message("query", query, appendLF = FALSE)
+    if (verbose) webchem_message("query", query, appendLF = FALSE)
     baseurl <- "https://webetox.uba.de/webETOX/public/search/stoff.do"
     if (from == 'name') {
       body <- list("stoffname.selection[0].name" = query,
@@ -127,7 +131,7 @@ get_etoxid <- function(query,
     }
   }
   out <- lapply(query, foo, from = from, match = match, verbose = verbose)
-  out <- dplyr::bind_rows(out)
+  out <- dplyr::bind_rows(out, .id = "query")
   return(out)
 }
 
@@ -172,6 +176,7 @@ get_etoxid <- function(query,
 etox_basic <- function(id, verbose = getOption("verbose")) {
 
   if (!ping_service("etox")) stop(webchem_message("service_down"))
+  names(id) <- id
 
   foo <- function(id, verbose) {
     if (is.na(id)) {
@@ -252,7 +257,6 @@ etox_basic <- function(id, verbose = getOption("verbose")) {
     }
     }
   out <- lapply(id, foo, verbose = verbose)
-  names(out) <- id
   class(out) <- c('etox_basic', 'list')
   return(out)
 }
@@ -291,8 +295,8 @@ etox_basic <- function(id, verbose = getOption("verbose")) {
 #'
 #' }
 etox_targets <- function(id, verbose = getOption("verbose")) {
-
   if (!ping_service("etox")) stop(webchem_message("service_down"))
+  names(id) <- id
 
   foo <- function(id, verbose) {
     if (is.na(id)) {
@@ -356,7 +360,6 @@ etox_targets <- function(id, verbose = getOption("verbose")) {
     }
   }
   out <- lapply(id, foo, verbose = verbose)
-  names(out) <- id
   return(out)
 }
 
@@ -390,7 +393,7 @@ etox_targets <- function(id, verbose = getOption("verbose")) {
 etox_tests <- function(id, verbose = getOption("verbose")) {
 
   if (!ping_service("etox")) stop(webchem_message("service_down"))
-
+  names(id) <- id
   foo <- function(id, verbose){
     if (is.na(id)) {
       if (verbose) webchem_message("na")
@@ -448,6 +451,5 @@ etox_tests <- function(id, verbose = getOption("verbose")) {
     }
   }
   out <- lapply(id, foo, verbose = verbose)
-  names(out) <- id
   return(out)
 }
