@@ -31,11 +31,6 @@ cas.opsin_query <- function(x, ...) {
   stop("CAS is not returned by this datasource!")
 }
 
-#' @export
-cas.pan_query <- function(x, ...) {
-  sapply(x, function(y) y$`CAS Number`)
-}
-
 #' @export
 cas.bcpc_query <- function(x, ...) {
   sapply(x, function(y) y$cas)
@@ -61,15 +56,6 @@ cas.etox_basic <- function(x, ...) {
   })
 }
 
-#' @export
-cas.ci_query <- function(x, ...) {
-  sapply(x, function(y) {
-    if (length(y) == 1 && is.na(y))
-      return(NA)
-    unique(y$cas)
-  })
-}
-
 # InChIKey ----------------------------------------------------------------
 #' @rdname extractors
 #' @export
@@ -103,11 +89,6 @@ inchikey.chebi_comp_entity <- function(x, ...) {
 inchikey.etox_basic <- function(x, ...) {
   stop("InChIkey is not returned by this datasource!")
 }
-#' @export
-inchikey.pan_query <- function(x, ...) {
-  stop("InChIkey is not returned by this datasource!")
-}
-
 #' @export
 inchikey.opsin_query <- function(x, ...) {
   x$stdinchikey
@@ -129,15 +110,6 @@ inchikey.cts_compinfo <- function(x, ...) {
   sapply(x, function(x) x$inchikey)
 }
 
-#' @export
-inchikey.ci_query <- function(x, ...) {
-  sapply(x, function(y) {
-    if (length(y) == 1 && is.na(y))
-      return(NA)
-    unique(y$inchikey)
-  })
-}
-
 # SMILES ------------------------------------------------------------------
 #' @rdname extractors
 #' @export
@@ -167,10 +139,6 @@ smiles.etox_basic <- function(x, ...) {
   stop("InChIkey is not returned by this datasource!")
 }
 #' @export
-smiles.pan_query <- function(x, ...) {
-  stop("SMILES is not returned by this datasource!")
-}
-#' @export
 smiles.opsin_query <- function(x, ...) {
   x$smiles
 }
@@ -189,12 +157,3 @@ smiles.pc_prop <- function(x, ...) {
 smiles.wd_ident <- function(x, ...) {
   x$smiles
 }
-
-#' @export
-smiles.ci_query <- function(x, ...) {
-  sapply(x, function(y) {
-    if (length(y) == 1 && is.na(y))
-      return(NA)
-    unique(y$smiles)
-  })
-}
