@@ -9,14 +9,13 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' ping_service("pan")
+#' ping_service("chembl")
 #' }
 ping_service <-
   function(service = c(
     "bcpc",
     "chebi",
     "chembl",
-    "ci",
     "cs",
     "cs_web",
     "cir",
@@ -25,7 +24,6 @@ ping_service <-
     "fn",
     "nist",
     "opsin",
-    "pan",
     "pc",
     "srs",
     "wd"
@@ -49,14 +47,12 @@ ping_service <-
         switch(service,
                "bcpc" = "https://pesticidecompendium.bcpc.org/introduction.html",
                "chembl" = "https://www.ebi.ac.uk/chembl/api/data/molecule/CHEMBL1082.json",
-               "ci" = "https://chem.nlm.nih.gov/chemidplus/rn/50-00-0",
                "cir" = "http://cactus.nci.nih.gov/chemical/structure/Triclosan/cas/xml",
                "cts" = "http://cts.fiehnlab.ucdavis.edu/service/compound/XEFQLINVKFYRCS-UHFFFAOYSA-N",
                "cs_web" = "http://www.chemspider.com/Chemical-Structure.5363.html",
                "fn" = "http://www.flavornet.org/info/121-33-5.html",
                "nist" = "https://webbook.nist.gov/cgi/cbook.cgi?Name=2-hexene&Units=SI",
                "opsin" = "https://opsin.ch.cam.ac.uk/opsin/cyclopropane.json",
-               "pan" = "http://www.pesticideinfo.org/List_Chemicals.jsp?",
                "srs" = "https://cdxnodengn.epa.gov/cdx-srs-rest/substance/name/triclosan",
                "wd" = "https://www.wikidata.org/w/api.php"
         )
