@@ -1,12 +1,13 @@
 # These all might occasionally fail because cts_translate() is currently
 # somewhat unreliable.
 
+etox_up <- ping_service("etox")
 fn_up <- ping_service("fn")
 up <- ping_service("cts")
 
 test_that("with_cts() works when no translation needed", {
   skip_on_cran()
-  skip_if_not(fn_up, "Flavornet down!")
+  skip_if_not(etox_up, "ETOX down!")
   skip_if_not(up, "CTS service down")
 
   CASs <- c("75-07-0",  "64-17-5")
@@ -14,14 +15,14 @@ test_that("with_cts() works when no translation needed", {
     with_cts(
       query = CASs,
       from = "cas",
-      .f = "fn_percept",
+      .f = "get_etoxid",
       .verbose = getOption("verbose")
     )
-  b <- fn_percept(CASs)
+  b <- get_etoxid(CASs, from = "cas")
   expect_equal(a, b)
 })
 
-etox_up <- ping_service("etox")
+
 test_that("with_cts() translates", {
   skip_on_cran()
   skip_if_not(etox_up, "ETOX down!")
@@ -47,4 +48,4 @@ test_that("find_db() function works", {
                etox = c(TRUE, FALSE, FALSE),
                fn = c(FALSE, FALSE, FALSE))
   expect_equal(out, df, ignore_attr = TRUE)
-})
\ No newline at end of file
+})
